@@ -22,6 +22,7 @@ if TYPE_CHECKING:
     from collections.abc import Sequence
     from pathlib import Path
 
+    from _griffe.docstrings.parsers import DocstringStyle
     from _griffe.enumerations import Parser
     from _griffe.expressions import Expr
 
@@ -36,7 +37,7 @@ def inspect(
     import_paths: Sequence[str | Path] | None = None,
     extensions: Extensions | None = None,
     parent: Module | None = None,
-    docstring_parser: Parser | None = None,
+    docstring_parser: DocstringStyle | Parser | None = None,
     docstring_options: dict[str, Any] | None = None,
     lines_collection: LinesCollection | None = None,
     modules_collection: ModulesCollection | None = None,
@@ -103,7 +104,7 @@ class Inspector:
         filepath: Path | None,
         extensions: Extensions,
         parent: Module | None = None,
-        docstring_parser: Parser | None = None,
+        docstring_parser: DocstringStyle | Parser | None = None,
         docstring_options: dict[str, Any] | None = None,
         lines_collection: LinesCollection | None = None,
         modules_collection: ModulesCollection | None = None,
@@ -137,7 +138,7 @@ class Inspector:
         self.current: Module | Class = None  # type: ignore[assignment]
         """The current object being inspected."""
 
-        self.docstring_parser: Parser | None = docstring_parser
+        self.docstring_parser: DocstringStyle | Parser | None = docstring_parser
         """The docstring parser to use."""
 
         self.docstring_options: dict[str, Any] = docstring_options or {}
@@ -153,7 +154,7 @@ class Inspector:
         try:
             # Access `__doc__` directly to avoid taking the `__doc__` attribute from a parent class.
             value = getattr(node.obj, "__doc__", None)
-        except Exception:  # noqa: BLE001  # getattr can trigger exceptions
+        except Exception:  # noqa: BLE001
             return None
         if value is None:
             return None
@@ -408,6 +409,14 @@ class Inspector:
         """
         self.handle_function(node, {"property"})
 
+    def inspect_getset_descriptor(self, node: ObjectNode) -> None:
+        """Inspect a get/set descriptor.
+
+        Parameters:
+            node: The node to inspect.
+        """
+        self.handle_function(node, {"property"})
+
     def handle_function(self, node: ObjectNode, labels: set | None = None) -> None:
         """Handle a function.
 
@@ -421,8 +430,8 @@ class Inspector:
         try:
             signature = getsignature(node.obj)
         except Exception:  # noqa: BLE001
-            # so many exceptions can be raised here:
-            # AttributeError, NameError, RuntimeError, ValueError, TokenError, TypeError
+            # So many exceptions can be raised here:
+            # AttributeError, NameError, RuntimeError, ValueError, TokenError, TypeError...
             parameters = None
             returns = None
         else:
@@ -517,7 +526,7 @@ class Inspector:
         parent.set_member(node.name, attribute)
 
         if node.name == "__all__":
-            parent.exports = set(node.obj)
+            parent.exports = list(node.obj)
         self.extensions.call("on_instance", node=node, obj=attribute, agent=self)
         self.extensions.call("on_attribute_instance", node=node, attr=attribute, agent=self)
 
@@ -540,7 +549,7 @@ def _convert_parameter(parameter: SignatureParameter, parent: Module | Class) ->
     if parameter.default is _empty:
         default = None
     elif hasattr(parameter.default, "__name__"):
-        # avoid repr containing chevrons and memory addresses
+        # Avoid `repr` containing chevrons and memory addresses.
         default = parameter.default.__name__
     else:
         default = repr(parameter.default)
@@ -548,17 +557,17 @@ def _convert_parameter(parameter: SignatureParameter, parent: Module | Class) ->
 
 
 def _convert_object_to_annotation(obj: Any, parent: Module | Class) -> str | Expr | None:
-    # even when *we* import future annotations,
+    # Even when *we* import future annotations,
     # the object from which we get a signature
     # can come from modules which did *not* import them,
-    # so inspect.signature returns actual Python objects
-    # that we must deal with
+    # so `inspect.signature` returns actual Python objects
+    # that we must deal with.
     if not isinstance(obj, str):
         if hasattr(obj, "__name__"):  # noqa: SIM108
-            # simple types like int, str, custom classes, etc.
+            # Simple types like `int`, `str`, custom classes, etc..
             obj = obj.__name__
         else:
-            # other, more complex types: hope for the best
+            # Other, more complex types: hope for the best.
             obj = repr(obj)
     try:
         annotation_node = compile(obj, mode="eval", filename="<>", flags=ast.PyCF_ONLY_AST, optimize=2)
