@@ -2,7 +2,6 @@
 
 from __future__ import annotations
 
-import sys
 from contextlib import suppress
 from datetime import datetime, timezone
 from pathlib import Path
@@ -31,10 +30,9 @@ from _griffe.stats import Stats
 if TYPE_CHECKING:
     from collections.abc import Sequence
 
+    from _griffe.docstrings.parsers import DocstringStyle
     from _griffe.enumerations import Parser
 
-_builtin_modules: set[str] = set(sys.builtin_module_names)
-
 
 class GriffeLoader:
     """The Griffe loader, allowing to load data from modules."""
@@ -50,7 +48,7 @@ class GriffeLoader:
         *,
         extensions: Extensions | None = None,
         search_paths: Sequence[str | Path] | None = None,
-        docstring_parser: Parser | None = None,
+        docstring_parser: DocstringStyle | Parser | None = None,
         docstring_options: dict[str, Any] | None = None,
         lines_collection: LinesCollection | None = None,
         modules_collection: ModulesCollection | None = None,
@@ -72,7 +70,7 @@ class GriffeLoader:
         """
         self.extensions: Extensions = extensions or load_extensions()
         """Loaded Griffe extensions."""
-        self.docstring_parser: Parser | None = docstring_parser
+        self.docstring_parser: DocstringStyle | Parser | None = docstring_parser
         """Selected docstring parser."""
         self.docstring_options: dict[str, Any] = docstring_options or {}
         """Configured parsing options."""
@@ -221,7 +219,7 @@ class GriffeLoader:
         if max_iterations is None:
             max_iterations = float("inf")  # type: ignore[assignment]
         prev_unresolved: set[str] = set()
-        unresolved: set[str] = set("0")  # init to enter loop
+        unresolved: set[str] = set("0")  # Init to enter loop.
         iteration = 0
         collection = self.modules_collection.members
 
@@ -271,12 +269,12 @@ class GriffeLoader:
         if module.exports is None:
             return
 
-        expanded = set()
+        expanded = []
         for export in module.exports:
             # It's a name: we resolve it, get the module it comes from,
             # recurse into it, and add its exports to the current ones.
             if isinstance(export, ExprName):
-                module_path = export.canonical_path.rsplit(".", 1)[0]  # remove trailing .__all__
+                module_path = export.canonical_path.rsplit(".", 1)[0]  # Remove trailing `.__all__`.
                 try:
                     next_module = self.modules_collection.get_member(module_path)
                 except KeyError:
@@ -284,13 +282,13 @@ class GriffeLoader:
                     continue
                 if next_module.path not in seen:
                     self.expand_exports(next_module, seen)
-                    try:
-                        expanded |= next_module.exports
-                    except TypeError:
-                        logger.warning("Unsupported item in %s.__all__: %s (use strings only)", module.path, export)
+                try:
+                    expanded += [export for export in next_module.exports if export not in expanded]
+                except TypeError:
+                    logger.warning("Unsupported item in %s.__all__: %s (use strings only)", module.path, export)
             # It's a string, simply add it to the current exports.
             else:
-                expanded.add(export)
+                expanded.append(export)
         module.exports = expanded
 
         # Make sure to expand exports in all modules.
@@ -323,7 +321,7 @@ class GriffeLoader:
         # while also keeping track of the members representing wildcard import, to remove them later.
         for member in obj.members.values():
             # Handle a wildcard.
-            if member.is_alias and member.wildcard:  # type: ignore[union-attr]  # we know it's an alias
+            if member.is_alias and member.wildcard:  # type: ignore[union-attr]
                 package = member.wildcard.split(".", 1)[0]  # type: ignore[union-attr]
                 not_loaded = obj.package.path != package and package not in self.modules_collection
 
@@ -345,7 +343,7 @@ class GriffeLoader:
                         "Could not expand wildcard import %s in %s: %s not found in modules collection",
                         member.name,
                         obj.path,
-                        cast(Alias, member).target_path,
+                        cast("Alias", member).target_path,
                     )
                     continue
 
@@ -373,7 +371,9 @@ class GriffeLoader:
         for new_member, alias_lineno, alias_endlineno in expanded:
             overwrite = False
             already_present = new_member.name in obj.members
-            self_alias = new_member.is_alias and cast(Alias, new_member).target_path == f"{obj.path}.{new_member.name}"
+            self_alias = (
+                new_member.is_alias and cast("Alias", new_member).target_path == f"{obj.path}.{new_member.name}"
+            )
 
             # If a member with the same name is already present in the current object,
             # we only overwrite it if the alias is imported lower in the module
@@ -506,7 +506,6 @@ class GriffeLoader:
 
     def _load_package(self, package: Package | NamespacePackage, *, submodules: bool = True) -> Module:
         top_module = self._load_module(package.name, package.path, submodules=submodules)
-        self.modules_collection.set_member(top_module.path, top_module)
         if isinstance(package, NamespacePackage):
             return top_module
         if package.stubs:
@@ -558,6 +557,8 @@ class GriffeLoader:
             module = self._inspect_module(module_name, module_path, parent)
         else:
             raise LoadingError("Cannot load compiled module without inspection")
+        if parent is None:
+            self.modules_collection.set_member(module.path, module)
         if submodules:
             self._load_submodules(module)
         return module
@@ -701,7 +702,7 @@ class GriffeLoader:
         return parent_module
 
     def _expand_wildcard(self, wildcard_obj: Alias) -> list[tuple[Object | Alias, int | None, int | None]]:
-        module = self.modules_collection.get_member(wildcard_obj.wildcard)  # type: ignore[arg-type]  # we know it's a wildcard
+        module = self.modules_collection.get_member(wildcard_obj.wildcard)  # type: ignore[arg-type]
         return [
             (imported_member, wildcard_obj.alias_lineno, wildcard_obj.alias_endlineno)
             for imported_member in module.members.values()
@@ -717,7 +718,7 @@ def load(
     try_relative_path: bool = True,
     extensions: Extensions | None = None,
     search_paths: Sequence[str | Path] | None = None,
-    docstring_parser: Parser | None = None,
+    docstring_parser: DocstringStyle | Parser | None = None,
     docstring_options: dict[str, Any] | None = None,
     lines_collection: LinesCollection | None = None,
     modules_collection: ModulesCollection | None = None,
@@ -823,7 +824,7 @@ def load_git(
     submodules: bool = True,
     extensions: Extensions | None = None,
     search_paths: Sequence[str | Path] | None = None,
-    docstring_parser: Parser | None = None,
+    docstring_parser: DocstringStyle | Parser | None = None,
     docstring_options: dict[str, Any] | None = None,
     lines_collection: LinesCollection | None = None,
     modules_collection: ModulesCollection | None = None,
@@ -907,7 +908,7 @@ def load_pypi(
     submodules: bool = True,  # noqa: ARG001
     extensions: Extensions | None = None,  # noqa: ARG001
     search_paths: Sequence[str | Path] | None = None,  # noqa: ARG001
-    docstring_parser: Parser | None = None,  # noqa: ARG001
+    docstring_parser: DocstringStyle | Parser | None = None,  # noqa: ARG001
     docstring_options: dict[str, Any] | None = None,  # noqa: ARG001
     lines_collection: LinesCollection | None = None,  # noqa: ARG001
     modules_collection: ModulesCollection | None = None,  # noqa: ARG001
