@@ -455,7 +455,7 @@ class Object(ObjectAliasMixin):
         while the values are the actual names of the objects (`from ... import REAL_NAME as ...`).
         """
 
-        self.exports: set[str] | list[str | ExprName] | None = None
+        self.exports: list[str | ExprName] | None = None
         """The names of the objects exported by this (module) object through the `__all__` variable.
 
         Exports can contain string (object names) or resolvable names,
@@ -494,7 +494,7 @@ class Object(ObjectAliasMixin):
         self._lines_collection: LinesCollection | None = lines_collection
         self._modules_collection: ModulesCollection | None = modules_collection
 
-        # attach the docstring to this object
+        # Attach the docstring to this object.
         if docstring:
             docstring.parent = self
 
@@ -754,7 +754,7 @@ class Object(ObjectAliasMixin):
         """
         module = self.module
         while module.parent:
-            module = module.parent  # type: ignore[assignment]  # always a module
+            module = module.parent  # type: ignore[assignment]
         return module
 
     @property
@@ -949,9 +949,8 @@ class Object(ObjectAliasMixin):
                 return self.members[name].target_path  # type: ignore[union-attr]
             return self.members[name].path
 
-        # Name unknown and no more parent scope.
+        # Name unknown and no more parent scope, could be a built-in.
         if self.parent is None:
-            # could be a built-in
             raise NameResolutionError(f"{name} could not be resolved in the scope of {self.path}")
 
         # Name is parent, non-module object.
@@ -1150,13 +1149,13 @@ class Alias(ObjectAliasMixin):
 
         See also: [`canonical_path`][griffe.Alias.canonical_path].
         """
-        return f"{self.parent.path}.{self.name}"  # type: ignore[union-attr]  # we assume there's always a parent
+        return f"{self.parent.path}.{self.name}"  # type: ignore[union-attr]
 
     @property
     def modules_collection(self) -> ModulesCollection:
         """The modules collection attached to the alias parents."""
-        # no need to forward to the target
-        return self.parent.modules_collection  # type: ignore[union-attr]  # we assume there's always a parent
+        # No need to forward to the target.
+        return self.parent.modules_collection  # type: ignore[union-attr]
 
     @property
     def members(self) -> dict[str, Object | Alias]:
@@ -1277,7 +1276,7 @@ class Alias(ObjectAliasMixin):
         return self.final_target.imports
 
     @property
-    def exports(self) -> set[str] | list[str | ExprName] | None:
+    def exports(self) -> list[str | ExprName] | None:
         """The names of the objects exported by this (module) object through the `__all__` variable.
 
         Exports can contain string (object names) or resolvable names,
@@ -1512,7 +1511,7 @@ class Alias(ObjectAliasMixin):
 
     @property
     def _filepath(self) -> Path | list[Path] | None:
-        return cast(Module, self.final_target)._filepath
+        return cast("Module", self.final_target)._filepath
 
     @property
     def bases(self) -> list[Expr | str]:
@@ -1522,7 +1521,7 @@ class Alias(ObjectAliasMixin):
         [`resolved_bases`][griffe.Alias.resolved_bases],
         [`mro`][griffe.Alias.mro].
         """
-        return cast(Class, self.final_target).bases
+        return cast("Class", self.final_target).bases
 
     @property
     def decorators(self) -> list[Decorator]:
@@ -1531,12 +1530,12 @@ class Alias(ObjectAliasMixin):
         See also: [`Function`][griffe.Function],
         [`Class`][griffe.Class].
         """
-        return cast(Union[Class, Function], self.target).decorators
+        return cast("Union[Class, Function]", self.target).decorators
 
     @property
     def imports_future_annotations(self) -> bool:
         """Whether this module import future annotations."""
-        return cast(Module, self.final_target).imports_future_annotations
+        return cast("Module", self.final_target).imports_future_annotations
 
     @property
     def is_init_module(self) -> bool:
@@ -1544,7 +1543,7 @@ class Alias(ObjectAliasMixin):
 
         See also: [`is_module`][griffe.Alias.is_module].
         """
-        return cast(Module, self.final_target).is_init_module
+        return cast("Module", self.final_target).is_init_module
 
     @property
     def is_package(self) -> bool:
@@ -1552,7 +1551,7 @@ class Alias(ObjectAliasMixin):
 
         See also: [`is_subpackage`][griffe.Alias.is_subpackage].
         """
-        return cast(Module, self.final_target).is_package
+        return cast("Module", self.final_target).is_package
 
     @property
     def is_subpackage(self) -> bool:
@@ -1560,7 +1559,7 @@ class Alias(ObjectAliasMixin):
 
         See also: [`is_package`][griffe.Alias.is_package].
         """
-        return cast(Module, self.final_target).is_subpackage
+        return cast("Module", self.final_target).is_subpackage
 
     @property
     def is_namespace_package(self) -> bool:
@@ -1568,7 +1567,7 @@ class Alias(ObjectAliasMixin):
 
         See also: [`is_namespace_subpackage`][griffe.Alias.is_namespace_subpackage].
         """
-        return cast(Module, self.final_target).is_namespace_package
+        return cast("Module", self.final_target).is_namespace_package
 
     @property
     def is_namespace_subpackage(self) -> bool:
@@ -1576,16 +1575,16 @@ class Alias(ObjectAliasMixin):
 
         See also: [`is_namespace_package`][griffe.Alias.is_namespace_package].
         """
-        return cast(Module, self.final_target).is_namespace_subpackage
+        return cast("Module", self.final_target).is_namespace_subpackage
 
     @property
     def overloads(self) -> dict[str, list[Function]] | list[Function] | None:
         """The overloaded signatures declared in this class/module or for this function."""
-        return cast(Union[Module, Class, Function], self.final_target).overloads
+        return cast("Union[Module, Class, Function]", self.final_target).overloads
 
     @overloads.setter
     def overloads(self, overloads: list[Function] | None) -> None:
-        cast(Union[Module, Class, Function], self.final_target).overloads = overloads
+        cast("Union[Module, Class, Function]", self.final_target).overloads = overloads
 
     @property
     def parameters(self) -> Parameters:
@@ -1595,40 +1594,40 @@ class Alias(ObjectAliasMixin):
         and therefore is part of the consumer API:
         do not use when producing Griffe trees!
         """
-        return cast(Union[Class, Function], self.final_target).parameters
+        return cast("Union[Class, Function]", self.final_target).parameters
 
     @property
     def returns(self) -> str | Expr | None:
         """The function return type annotation."""
-        return cast(Function, self.final_target).returns
+        return cast("Function", self.final_target).returns
 
     @returns.setter
     def returns(self, returns: str | Expr | None) -> None:
-        cast(Function, self.final_target).returns = returns
+        cast("Function", self.final_target).returns = returns
 
     @property
     def setter(self) -> Function | None:
         """The setter linked to this function (property)."""
-        return cast(Attribute, self.final_target).setter
+        return cast("Attribute", self.final_target).setter
 
     @property
     def deleter(self) -> Function | None:
         """The deleter linked to this function (property)."""
-        return cast(Attribute, self.final_target).deleter
+        return cast("Attribute", self.final_target).deleter
 
     @property
     def value(self) -> str | Expr | None:
         """The attribute value."""
-        return cast(Attribute, self.final_target).value
+        return cast("Attribute", self.final_target).value
 
     @property
     def annotation(self) -> str | Expr | None:
         """The attribute type annotation."""
-        return cast(Attribute, self.final_target).annotation
+        return cast("Attribute", self.final_target).annotation
 
     @annotation.setter
     def annotation(self, annotation: str | Expr | None) -> None:
-        cast(Attribute, self.final_target).annotation = annotation
+        cast("Attribute", self.final_target).annotation = annotation
 
     @property
     def resolved_bases(self) -> list[Object]:
@@ -1637,11 +1636,11 @@ class Alias(ObjectAliasMixin):
         This method is part of the consumer API:
         do not use when producing Griffe trees!
         """
-        return cast(Class, self.final_target).resolved_bases
+        return cast("Class", self.final_target).resolved_bases
 
     def mro(self) -> list[Class]:
         """Return a list of classes in order corresponding to Python's MRO."""
-        return cast(Class, self.final_target).mro()
+        return cast("Class", self.final_target).mro()
 
     # SPECIFIC ALIAS METHOD AND PROPERTIES -----------------
     # These methods and properties do not exist on targets,
@@ -1660,7 +1659,7 @@ class Alias(ObjectAliasMixin):
         """
         if not self.resolved:
             self.resolve_target()
-        return self._target  # type: ignore[return-value]  # cannot return None, exception is raised
+        return self._target  # type: ignore[return-value]
 
     @target.setter
     def target(self, value: Object | Alias) -> None:
@@ -1687,7 +1686,7 @@ class Alias(ObjectAliasMixin):
         # The cycle detection is needed because alias chains can be created
         # as already resolved, and can contain cycles.
 
-        # using a dict as an ordered set
+        # Using a dict as an ordered set.
         paths_seen: dict[str, None] = {}
         target = self
         while target.is_alias:
@@ -1744,7 +1743,7 @@ class Alias(ObjectAliasMixin):
                 raise CyclicAliasError([self.target_path, *error.chain]) from error
         self._target = resolved
         if self.parent is not None:
-            self._target.aliases[self.path] = self  # type: ignore[union-attr]  # we just set the target
+            self._target.aliases[self.path] = self  # type: ignore[union-attr]
 
     def _update_target_aliases(self) -> None:
         with suppress(AttributeError, AliasResolutionError, CyclicAliasError):
@@ -1889,7 +1888,8 @@ class Module(Object):
                 self.parent is not None
                 and isinstance(self.filepath, list)
                 and (
-                    cast(Module, self.parent).is_namespace_package or cast(Module, self.parent).is_namespace_subpackage
+                    cast("Module", self.parent).is_namespace_package
+                    or cast("Module", self.parent).is_namespace_subpackage
                 )
             )
         except BuiltinModuleError:
@@ -1978,7 +1978,7 @@ class Class(Object):
         for base in self.bases:
             base_path = base if isinstance(base, str) else base.canonical_path
             try:
-                resolved_base = self.modules_collection[base_path]
+                resolved_base = self.modules_collection.get_member(base_path)
                 if resolved_base.is_alias:
                     resolved_base = resolved_base.final_target
             except (AliasResolutionError, CyclicAliasError, KeyError):
@@ -2004,7 +2004,7 @@ class Class(Object):
         See also: [`bases`][griffe.Class.bases],
         [`resolved_bases`][griffe.Class.resolved_bases].
         """
-        return self._mro()[1:]  # remove self
+        return self._mro()[1:]  # Remove self.
 
     def as_dict(self, **kwargs: Any) -> dict[str, Any]:
         """Return this class' data as a dictionary.
@@ -2063,6 +2063,23 @@ class Function(Object):
         """The type annotation of the returned value."""
         return self.returns
 
+    def resolve(self, name: str) -> str:
+        """Resolve a name within this object's and parents' scope.
+
+        Parameters:
+            name: The name to resolve.
+
+        Raises:
+            NameResolutionError: When the name could not be resolved.
+
+        Returns:
+            The resolved name.
+        """
+        # We're in an `__init__` method and name is a parameter name.
+        if self.parent and self.name == "__init__" and name in self.parameters:
+            return f"{self.parent.path}({name})"
+        return super().resolve(name)
+
     def as_dict(self, **kwargs: Any) -> dict[str, Any]:
         """Return this function's data as a dictionary.
 
